@@ -11,6 +11,7 @@ namespace PHPUnit\Framework\Constraint;
 
 use const DIRECTORY_SEPARATOR;
 use const PHP_EOL;
+use function assert;
 use function explode;
 use function implode;
 use function preg_match;
@@ -125,7 +126,11 @@ final class StringMatchesFormatDescription extends Constraint
 
     private function convertNewlines(string $text): string
     {
-        return preg_replace('/\r\n/', "\n", $text);
+        $result = preg_replace('/\r\n/', "\n", $text);
+
+        assert($result !== null);
+
+        return $result;
     }
 
     private function differ(): Differ
