@@ -27,6 +27,7 @@ trait Method
         return $this
             ->__phpunit_getInvocationHandler()
             ->expects(new AnyInvokedCount)
-            ->method($constraint);
+            ->method($constraint)
+            ->markAsCreatedWithoutExplicitExpects();
     }
 }
