@@ -1002,6 +1002,14 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
      */
     final protected function atLeast(int $requiredInvocations): InvokedAtLeastCountMatcher
     {
+        if ($requiredInvocations < 1) {
+            Event\Facade::emitter()->testTriggeredPhpunitDeprecation(
+                $this->valueObjectForEvents(),
+                'Calling atLeast() with an argument that is not positive is deprecated.' . PHP_EOL .
+                'This will become an error in PHPUnit 14.',
+            );
+        }
+
         return new InvokedAtLeastCountMatcher(
             $requiredInvocations,
         );
@@ -1429,8 +1437,10 @@ abstract class TestCase extends Assert implements Reorderable, SelfDescribing, T
                 );
             }
 
-            if (!$mockObject->__phpunit_hasMatchers()) {
-                if (!$allowsMockObjectsWithoutExpectations && !$isPhpunitTestSuite) {
+            if (!$mockObject->__phpunit_hasInvocationCountRule()) {
+                if (!$mockObject->__phpunit_hasParametersRule() &&
+                    !$allowsMockObjectsWithoutExpectations &&
+                    !$isPhpunitTestSuite) {
                     Event\Facade::emitter()->testTriggeredPhpunitNotice(
                         $this->testValueObjectForEvents,
                         sprintf(
