@@ -16,5 +16,5 @@ namespace PHPUnit\Framework;
  */
 interface IsolatedTestRunner
 {
-    public function run(TestCase $test, bool $runEntireClass, bool $preserveGlobalState, bool $requiresXdebug): void;
+    public function run(TestCase $test, bool $preserveGlobalState, bool $requiresXdebug): void;
 }
