@@ -25,6 +25,7 @@ use function is_float;
 use function is_int;
 use function is_object;
 use function is_scalar;
+use function is_string;
 use function method_exists;
 use function preg_quote;
 use function preg_replace;
@@ -119,6 +120,8 @@ final class NamePrettifier
 
         $result = preg_replace('/(?<=[[:lower:]])(?=[[:upper:]])/u', ' ', $className);
 
+        assert($result !== null);
+
         if ($fullyQualifiedName !== $className) {
             return $result . ' (' . $fullyQualifiedName . ')';
         }
@@ -289,9 +292,6 @@ final class NamePrettifier
         return $providedData;
     }
 
-    /**
-     * @return non-empty-string
-     */
     private function objectToString(object $value): string
     {
         $reflector = new ReflectionObject($value);
@@ -303,11 +303,11 @@ final class NamePrettifier
                 return (string) $value->value;
             }
 
-            return $value->name;
+            return (string) $value->name;
         }
 
         if ($reflector->hasMethod('__toString')) {
-            return $value->__toString();
+            return (string) $value;
         }
 
         return $value::class;
@@ -339,6 +339,8 @@ final class NamePrettifier
             $placeholdersUsed = true;
         }
 
+        assert($result !== null);
+
         return [$result, $placeholdersUsed];
     }
 
@@ -403,7 +405,11 @@ final class NamePrettifier
         }
 
         try {
-            return [$reflector->invokeArgs(null, array_values($test->providedData())), true];
+            $result = $reflector->invokeArgs(null, array_values($test->providedData()));
+
+            assert(is_string($result));
+
+            return [$result, true];
         } catch (Throwable $t) {
             EventFacade::emitter()->testTriggeredPhpunitError(
                 TestMethodBuilder::fromTestCase($test, false),
