@@ -19,62 +19,56 @@ use PHPUnit\Runner\Extension\Extension;
  */
 abstract readonly class Metadata
 {
-    private const int CLASS_LEVEL  = 0;
-    private const int METHOD_LEVEL = 1;
-
-    /**
-     * @var int<0, 1>
-     */
-    private int $level;
+    private Level $level;
 
     public static function after(int $priority): After
     {
-        return new After(self::METHOD_LEVEL, $priority);
+        return new After(Level::METHOD_LEVEL, $priority);
     }
 
     public static function afterClass(int $priority): AfterClass
     {
-        return new AfterClass(self::METHOD_LEVEL, $priority);
+        return new AfterClass(Level::METHOD_LEVEL, $priority);
     }
 
     public static function allowMockObjectsWithoutExpectationsOnClass(): AllowMockObjectsWithoutExpectations
     {
-        return new AllowMockObjectsWithoutExpectations(self::CLASS_LEVEL);
+        return new AllowMockObjectsWithoutExpectations(Level::CLASS_LEVEL);
     }
 
     public static function allowMockObjectsWithoutExpectationsOnMethod(): AllowMockObjectsWithoutExpectations
     {
-        return new AllowMockObjectsWithoutExpectations(self::METHOD_LEVEL);
+        return new AllowMockObjectsWithoutExpectations(Level::METHOD_LEVEL);
     }
 
     public static function backupGlobalsOnClass(bool $enabled): BackupGlobals
     {
-        return new BackupGlobals(self::CLASS_LEVEL, $enabled);
+        return new BackupGlobals(Level::CLASS_LEVEL, $enabled);
     }
 
     public static function backupGlobalsOnMethod(bool $enabled): BackupGlobals
     {
-        return new BackupGlobals(self::METHOD_LEVEL, $enabled);
+        return new BackupGlobals(Level::METHOD_LEVEL, $enabled);
     }
 
     public static function backupStaticPropertiesOnClass(bool $enabled): BackupStaticProperties
     {
-        return new BackupStaticProperties(self::CLASS_LEVEL, $enabled);
+        return new BackupStaticProperties(Level::CLASS_LEVEL, $enabled);
     }
 
     public static function backupStaticPropertiesOnMethod(bool $enabled): BackupStaticProperties
     {
-        return new BackupStaticProperties(self::METHOD_LEVEL, $enabled);
+        return new BackupStaticProperties(Level::METHOD_LEVEL, $enabled);
     }
 
     public static function before(int $priority): Before
     {
-        return new Before(self::METHOD_LEVEL, $priority);
+        return new Before(Level::METHOD_LEVEL, $priority);
     }
 
     public static function beforeClass(int $priority): BeforeClass
     {
-        return new BeforeClass(self::METHOD_LEVEL, $priority);
+        return new BeforeClass(Level::METHOD_LEVEL, $priority);
     }
 
     /**
@@ -82,7 +76,7 @@ abstract readonly class Metadata
      */
     public static function coversNamespace(string $namespace): CoversNamespace
     {
-        return new CoversNamespace(self::CLASS_LEVEL, $namespace);
+        return new CoversNamespace(Level::CLASS_LEVEL, $namespace);
     }
 
     /**
@@ -90,7 +84,7 @@ abstract readonly class Metadata
      */
     public static function coversClass(string $className): CoversClass
     {
-        return new CoversClass(self::CLASS_LEVEL, $className);
+        return new CoversClass(Level::CLASS_LEVEL, $className);
     }
 
     /**
@@ -98,7 +92,7 @@ abstract readonly class Metadata
      */
     public static function coversClassesThatExtendClass(string $className): CoversClassesThatExtendClass
     {
-        return new CoversClassesThatExtendClass(self::CLASS_LEVEL, $className);
+        return new CoversClassesThatExtendClass(Level::CLASS_LEVEL, $className);
     }
 
     /**
@@ -106,7 +100,7 @@ abstract readonly class Metadata
      */
     public static function coversClassesThatImplementInterface(string $interfaceName): CoversClassesThatImplementInterface
     {
-        return new CoversClassesThatImplementInterface(self::CLASS_LEVEL, $interfaceName);
+        return new CoversClassesThatImplementInterface(Level::CLASS_LEVEL, $interfaceName);
     }
 
     /**
@@ -114,7 +108,7 @@ abstract readonly class Metadata
      */
     public static function coversTrait(string $traitName): CoversTrait
     {
-        return new CoversTrait(self::CLASS_LEVEL, $traitName);
+        return new CoversTrait(Level::CLASS_LEVEL, $traitName);
     }
 
     /**
@@ -123,7 +117,7 @@ abstract readonly class Metadata
      */
     public static function coversMethod(string $className, string $methodName): CoversMethod
     {
-        return new CoversMethod(self::CLASS_LEVEL, $className, $methodName);
+        return new CoversMethod(Level::CLASS_LEVEL, $className, $methodName);
     }
 
     /**
@@ -131,17 +125,17 @@ abstract readonly class Metadata
      */
     public static function coversFunction(string $functionName): CoversFunction
     {
-        return new CoversFunction(self::CLASS_LEVEL, $functionName);
+        return new CoversFunction(Level::CLASS_LEVEL, $functionName);
     }
 
     public static function coversNothingOnClass(): CoversNothing
     {
-        return new CoversNothing(self::CLASS_LEVEL);
+        return new CoversNothing(Level::CLASS_LEVEL);
     }
 
     public static function coversNothingOnMethod(): CoversNothing
     {
-        return new CoversNothing(self::METHOD_LEVEL);
+        return new CoversNothing(Level::METHOD_LEVEL);
     }
 
     /**
@@ -150,7 +144,7 @@ abstract readonly class Metadata
      */
     public static function dataProvider(string $className, string $methodName, bool $validateArgumentCount): DataProvider
     {
-        return new DataProvider(self::METHOD_LEVEL, $className, $methodName, $validateArgumentCount);
+        return new DataProvider(Level::METHOD_LEVEL, $className, $methodName, $validateArgumentCount);
     }
 
     /**
@@ -158,7 +152,7 @@ abstract readonly class Metadata
      */
     public static function dependsOnClass(string $className, bool $deepClone, bool $shallowClone): DependsOnClass
     {
-        return new DependsOnClass(self::METHOD_LEVEL, $className, $deepClone, $shallowClone);
+        return new DependsOnClass(Level::METHOD_LEVEL, $className, $deepClone, $shallowClone);
     }
 
     /**
@@ -167,22 +161,22 @@ abstract readonly class Metadata
      */
     public static function dependsOnMethod(string $className, string $methodName, bool $deepClone, bool $shallowClone): DependsOnMethod
     {
-        return new DependsOnMethod(self::METHOD_LEVEL, $className, $methodName, $deepClone, $shallowClone);
+        return new DependsOnMethod(Level::METHOD_LEVEL, $className, $methodName, $deepClone, $shallowClone);
     }
 
     public static function disableReturnValueGenerationForTestDoubles(): DisableReturnValueGenerationForTestDoubles
     {
-        return new DisableReturnValueGenerationForTestDoubles(self::CLASS_LEVEL);
+        return new DisableReturnValueGenerationForTestDoubles(Level::CLASS_LEVEL);
     }
 
     public static function doesNotPerformAssertionsOnClass(): DoesNotPerformAssertions
     {
-        return new DoesNotPerformAssertions(self::CLASS_LEVEL);
+        return new DoesNotPerformAssertions(Level::CLASS_LEVEL);
     }
 
     public static function doesNotPerformAssertionsOnMethod(): DoesNotPerformAssertions
     {
-        return new DoesNotPerformAssertions(self::METHOD_LEVEL);
+        return new DoesNotPerformAssertions(Level::METHOD_LEVEL);
     }
 
     /**
@@ -190,7 +184,7 @@ abstract readonly class Metadata
      */
     public static function excludeGlobalVariableFromBackupOnClass(string $globalVariableName): ExcludeGlobalVariableFromBackup
     {
-        return new ExcludeGlobalVariableFromBackup(self::CLASS_LEVEL, $globalVariableName);
+        return new ExcludeGlobalVariableFromBackup(Level::CLASS_LEVEL, $globalVariableName);
     }
 
     /**
@@ -198,7 +192,7 @@ abstract readonly class Metadata
      */
     public static function excludeGlobalVariableFromBackupOnMethod(string $globalVariableName): ExcludeGlobalVariableFromBackup
     {
-        return new ExcludeGlobalVariableFromBackup(self::METHOD_LEVEL, $globalVariableName);
+        return new ExcludeGlobalVariableFromBackup(Level::METHOD_LEVEL, $globalVariableName);
     }
 
     /**
@@ -207,7 +201,7 @@ abstract readonly class Metadata
      */
     public static function excludeStaticPropertyFromBackupOnClass(string $className, string $propertyName): ExcludeStaticPropertyFromBackup
     {
-        return new ExcludeStaticPropertyFromBackup(self::CLASS_LEVEL, $className, $propertyName);
+        return new ExcludeStaticPropertyFromBackup(Level::CLASS_LEVEL, $className, $propertyName);
     }
 
     /**
@@ -216,7 +210,7 @@ abstract readonly class Metadata
      */
     public static function excludeStaticPropertyFromBackupOnMethod(string $className, string $propertyName): ExcludeStaticPropertyFromBackup
     {
-        return new ExcludeStaticPropertyFromBackup(self::METHOD_LEVEL, $className, $propertyName);
+        return new ExcludeStaticPropertyFromBackup(Level::METHOD_LEVEL, $className, $propertyName);
     }
 
     /**
@@ -224,7 +218,7 @@ abstract readonly class Metadata
      */
     public static function groupOnClass(string $groupName): Group
     {
-        return new Group(self::CLASS_LEVEL, $groupName);
+        return new Group(Level::CLASS_LEVEL, $groupName);
     }
 
     /**
@@ -232,7 +226,7 @@ abstract readonly class Metadata
      */
     public static function groupOnMethod(string $groupName): Group
     {
-        return new Group(self::METHOD_LEVEL, $groupName);
+        return new Group(Level::METHOD_LEVEL, $groupName);
     }
 
     /**
@@ -240,7 +234,7 @@ abstract readonly class Metadata
      */
     public static function ignoreDeprecationsOnClass(?string $messagePattern = null): IgnoreDeprecations
     {
-        return new IgnoreDeprecations(self::CLASS_LEVEL, $messagePattern);
+        return new IgnoreDeprecations(Level::CLASS_LEVEL, $messagePattern);
     }
 
     /**
@@ -248,7 +242,7 @@ abstract readonly class Metadata
      */
     public static function ignoreDeprecationsOnMethod(?string $messagePattern = null): IgnoreDeprecations
     {
-        return new IgnoreDeprecations(self::METHOD_LEVEL, $messagePattern);
+        return new IgnoreDeprecations(Level::METHOD_LEVEL, $messagePattern);
     }
 
     /**
@@ -256,7 +250,7 @@ abstract readonly class Metadata
      */
     public static function ignorePhpunitDeprecationsOnClass(): IgnorePhpunitDeprecations
     {
-        return new IgnorePhpunitDeprecations(self::CLASS_LEVEL);
+        return new IgnorePhpunitDeprecations(Level::CLASS_LEVEL);
     }
 
     /**
@@ -264,27 +258,27 @@ abstract readonly class Metadata
      */
     public static function ignorePhpunitDeprecationsOnMethod(): IgnorePhpunitDeprecations
     {
-        return new IgnorePhpunitDeprecations(self::METHOD_LEVEL);
+        return new IgnorePhpunitDeprecations(Level::METHOD_LEVEL);
     }
 
     public static function postCondition(int $priority): PostCondition
     {
-        return new PostCondition(self::METHOD_LEVEL, $priority);
+        return new PostCondition(Level::METHOD_LEVEL, $priority);
     }
 
     public static function preCondition(int $priority): PreCondition
     {
-        return new PreCondition(self::METHOD_LEVEL, $priority);
+        return new PreCondition(Level::METHOD_LEVEL, $priority);
     }
 
     public static function preserveGlobalStateOnClass(bool $enabled): PreserveGlobalState
     {
-        return new PreserveGlobalState(self::CLASS_LEVEL, $enabled);
+        return new PreserveGlobalState(Level::CLASS_LEVEL, $enabled);
     }
 
     public static function preserveGlobalStateOnMethod(bool $enabled): PreserveGlobalState
     {
-        return new PreserveGlobalState(self::METHOD_LEVEL, $enabled);
+        return new PreserveGlobalState(Level::METHOD_LEVEL, $enabled);
     }
 
     /**
@@ -292,7 +286,7 @@ abstract readonly class Metadata
      */
     public static function requiresFunctionOnClass(string $functionName): RequiresFunction
     {
-        return new RequiresFunction(self::CLASS_LEVEL, $functionName);
+        return new RequiresFunction(Level::CLASS_LEVEL, $functionName);
     }
 
     /**
@@ -300,7 +294,7 @@ abstract readonly class Metadata
      */
     public static function requiresFunctionOnMethod(string $functionName): RequiresFunction
     {
-        return new RequiresFunction(self::METHOD_LEVEL, $functionName);
+        return new RequiresFunction(Level::METHOD_LEVEL, $functionName);
     }
 
     /**
@@ -309,7 +303,7 @@ abstract readonly class Metadata
      */
     public static function requiresMethodOnClass(string $className, string $methodName): RequiresMethod
     {
-        return new RequiresMethod(self::CLASS_LEVEL, $className, $methodName);
+        return new RequiresMethod(Level::CLASS_LEVEL, $className, $methodName);
     }
 
     /**
@@ -318,7 +312,7 @@ abstract readonly class Metadata
      */
     public static function requiresMethodOnMethod(string $className, string $methodName): RequiresMethod
     {
-        return new RequiresMethod(self::METHOD_LEVEL, $className, $methodName);
+        return new RequiresMethod(Level::METHOD_LEVEL, $className, $methodName);
     }
 
     /**
@@ -326,7 +320,7 @@ abstract readonly class Metadata
      */
     public static function requiresOperatingSystemOnClass(string $operatingSystem): RequiresOperatingSystem
     {
-        return new RequiresOperatingSystem(self::CLASS_LEVEL, $operatingSystem);
+        return new RequiresOperatingSystem(Level::CLASS_LEVEL, $operatingSystem);
     }
 
     /**
@@ -334,7 +328,7 @@ abstract readonly class Metadata
      */
     public static function requiresOperatingSystemOnMethod(string $operatingSystem): RequiresOperatingSystem
     {
-        return new RequiresOperatingSystem(self::METHOD_LEVEL, $operatingSystem);
+        return new RequiresOperatingSystem(Level::METHOD_LEVEL, $operatingSystem);
     }
 
     /**
@@ -342,7 +336,7 @@ abstract readonly class Metadata
      */
     public static function requiresOperatingSystemFamilyOnClass(string $operatingSystemFamily): RequiresOperatingSystemFamily
     {
-        return new RequiresOperatingSystemFamily(self::CLASS_LEVEL, $operatingSystemFamily);
+        return new RequiresOperatingSystemFamily(Level::CLASS_LEVEL, $operatingSystemFamily);
     }
 
     /**
@@ -350,17 +344,17 @@ abstract readonly class Metadata
      */
     public static function requiresOperatingSystemFamilyOnMethod(string $operatingSystemFamily): RequiresOperatingSystemFamily
     {
-        return new RequiresOperatingSystemFamily(self::METHOD_LEVEL, $operatingSystemFamily);
+        return new RequiresOperatingSystemFamily(Level::METHOD_LEVEL, $operatingSystemFamily);
     }
 
     public static function requiresPhpOnClass(Requirement $versionRequirement): RequiresPhp
     {
-        return new RequiresPhp(self::CLASS_LEVEL, $versionRequirement);
+        return new RequiresPhp(Level::CLASS_LEVEL, $versionRequirement);
     }
 
     public static function requiresPhpOnMethod(Requirement $versionRequirement): RequiresPhp
     {
-        return new RequiresPhp(self::METHOD_LEVEL, $versionRequirement);
+        return new RequiresPhp(Level::METHOD_LEVEL, $versionRequirement);
     }
 
     /**
@@ -368,7 +362,7 @@ abstract readonly class Metadata
      */
     public static function requiresPhpExtensionOnClass(string $extension, ?Requirement $versionRequirement): RequiresPhpExtension
     {
-        return new RequiresPhpExtension(self::CLASS_LEVEL, $extension, $versionRequirement);
+        return new RequiresPhpExtension(Level::CLASS_LEVEL, $extension, $versionRequirement);
     }
 
     /**
@@ -376,17 +370,17 @@ abstract readonly class Metadata
      */
     public static function requiresPhpExtensionOnMethod(string $extension, ?Requirement $versionRequirement): RequiresPhpExtension
     {
-        return new RequiresPhpExtension(self::METHOD_LEVEL, $extension, $versionRequirement);
+        return new RequiresPhpExtension(Level::METHOD_LEVEL, $extension, $versionRequirement);
     }
 
     public static function requiresPhpunitOnClass(Requirement $versionRequirement): RequiresPhpunit
     {
-        return new RequiresPhpunit(self::CLASS_LEVEL, $versionRequirement);
+        return new RequiresPhpunit(Level::CLASS_LEVEL, $versionRequirement);
     }
 
     public static function requiresPhpunitOnMethod(Requirement $versionRequirement): RequiresPhpunit
     {
-        return new RequiresPhpunit(self::METHOD_LEVEL, $versionRequirement);
+        return new RequiresPhpunit(Level::METHOD_LEVEL, $versionRequirement);
     }
 
     /**
@@ -394,7 +388,7 @@ abstract readonly class Metadata
      */
     public static function requiresPhpunitExtensionOnClass(string $extensionClass): RequiresPhpunitExtension
     {
-        return new RequiresPhpunitExtension(self::CLASS_LEVEL, $extensionClass);
+        return new RequiresPhpunitExtension(Level::CLASS_LEVEL, $extensionClass);
     }
 
     /**
@@ -402,27 +396,27 @@ abstract readonly class Metadata
      */
     public static function requiresPhpunitExtensionOnMethod(string $extensionClass): RequiresPhpunitExtension
     {
-        return new RequiresPhpunitExtension(self::METHOD_LEVEL, $extensionClass);
+        return new RequiresPhpunitExtension(Level::METHOD_LEVEL, $extensionClass);
     }
 
     public static function requiresEnvironmentVariableOnClass(string $environmentVariableName, null|string $value): RequiresEnvironmentVariable
     {
-        return new RequiresEnvironmentVariable(self::CLASS_LEVEL, $environmentVariableName, $value);
+        return new RequiresEnvironmentVariable(Level::CLASS_LEVEL, $environmentVariableName, $value);
     }
 
     public static function requiresEnvironmentVariableOnMethod(string $environmentVariableName, null|string $value): RequiresEnvironmentVariable
     {
-        return new RequiresEnvironmentVariable(self::METHOD_LEVEL, $environmentVariableName, $value);
+        return new RequiresEnvironmentVariable(Level::METHOD_LEVEL, $environmentVariableName, $value);
     }
 
     public static function withEnvironmentVariableOnClass(string $environmentVariableName, null|string $value): WithEnvironmentVariable
     {
-        return new WithEnvironmentVariable(self::CLASS_LEVEL, $environmentVariableName, $value);
+        return new WithEnvironmentVariable(Level::CLASS_LEVEL, $environmentVariableName, $value);
     }
 
     public static function withEnvironmentVariableOnMethod(string $environmentVariableName, null|string $value): WithEnvironmentVariable
     {
-        return new WithEnvironmentVariable(self::METHOD_LEVEL, $environmentVariableName, $value);
+        return new WithEnvironmentVariable(Level::METHOD_LEVEL, $environmentVariableName, $value);
     }
 
     /**
@@ -431,7 +425,7 @@ abstract readonly class Metadata
      */
     public static function requiresSettingOnClass(string $setting, string $value): RequiresSetting
     {
-        return new RequiresSetting(self::CLASS_LEVEL, $setting, $value);
+        return new RequiresSetting(Level::CLASS_LEVEL, $setting, $value);
     }
 
     /**
@@ -440,27 +434,22 @@ abstract readonly class Metadata
      */
     public static function requiresSettingOnMethod(string $setting, string $value): RequiresSetting
     {
-        return new RequiresSetting(self::METHOD_LEVEL, $setting, $value);
-    }
-
-    public static function runClassInSeparateProcess(): RunClassInSeparateProcess
-    {
-        return new RunClassInSeparateProcess(self::CLASS_LEVEL);
+        return new RequiresSetting(Level::METHOD_LEVEL, $setting, $value);
     }
 
     public static function runTestsInSeparateProcesses(): RunTestsInSeparateProcesses
     {
-        return new RunTestsInSeparateProcesses(self::CLASS_LEVEL);
+        return new RunTestsInSeparateProcesses(Level::CLASS_LEVEL);
     }
 
     public static function runInSeparateProcess(): RunInSeparateProcess
     {
-        return new RunInSeparateProcess(self::METHOD_LEVEL);
+        return new RunInSeparateProcess(Level::METHOD_LEVEL);
     }
 
     public static function test(): Test
     {
-        return new Test(self::METHOD_LEVEL);
+        return new Test(Level::METHOD_LEVEL);
     }
 
     /**
@@ -468,7 +457,7 @@ abstract readonly class Metadata
      */
     public static function testDoxOnClass(string $text): TestDox
     {
-        return new TestDox(self::CLASS_LEVEL, $text);
+        return new TestDox(Level::CLASS_LEVEL, $text);
     }
 
     /**
@@ -476,7 +465,7 @@ abstract readonly class Metadata
      */
     public static function testDoxOnMethod(string $text): TestDox
     {
-        return new TestDox(self::METHOD_LEVEL, $text);
+        return new TestDox(Level::METHOD_LEVEL, $text);
     }
 
     /**
@@ -485,7 +474,7 @@ abstract readonly class Metadata
      */
     public static function testDoxFormatter(string $className, string $methodName): TestDoxFormatter
     {
-        return new TestDoxFormatter(self::METHOD_LEVEL, $className, $methodName);
+        return new TestDoxFormatter(Level::METHOD_LEVEL, $className, $methodName);
     }
 
     /**
@@ -493,7 +482,7 @@ abstract readonly class Metadata
      */
     public static function testWith(mixed $data, ?string $name = null): TestWith
     {
-        return new TestWith(self::METHOD_LEVEL, $data, $name);
+        return new TestWith(Level::METHOD_LEVEL, $data, $name);
     }
 
     /**
@@ -501,7 +490,7 @@ abstract readonly class Metadata
      */
     public static function usesNamespace(string $namespace): UsesNamespace
     {
-        return new UsesNamespace(self::CLASS_LEVEL, $namespace);
+        return new UsesNamespace(Level::CLASS_LEVEL, $namespace);
     }
 
     /**
@@ -509,7 +498,7 @@ abstract readonly class Metadata
      */
     public static function usesClass(string $className): UsesClass
     {
-        return new UsesClass(self::CLASS_LEVEL, $className);
+        return new UsesClass(Level::CLASS_LEVEL, $className);
     }
 
     /**
@@ -517,7 +506,7 @@ abstract readonly class Metadata
      */
     public static function usesClassesThatExtendClass(string $className): UsesClassesThatExtendClass
     {
-        return new UsesClassesThatExtendClass(self::CLASS_LEVEL, $className);
+        return new UsesClassesThatExtendClass(Level::CLASS_LEVEL, $className);
     }
 
     /**
@@ -525,7 +514,7 @@ abstract readonly class Metadata
      */
     public static function usesClassesThatImplementInterface(string $interfaceName): UsesClassesThatImplementInterface
     {
-        return new UsesClassesThatImplementInterface(self::CLASS_LEVEL, $interfaceName);
+        return new UsesClassesThatImplementInterface(Level::CLASS_LEVEL, $interfaceName);
     }
 
     /**
@@ -533,7 +522,7 @@ abstract readonly class Metadata
      */
     public static function usesTrait(string $traitName): UsesTrait
     {
-        return new UsesTrait(self::CLASS_LEVEL, $traitName);
+        return new UsesTrait(Level::CLASS_LEVEL, $traitName);
     }
 
     /**
@@ -541,7 +530,7 @@ abstract readonly class Metadata
      */
     public static function usesFunction(string $functionName): UsesFunction
     {
-        return new UsesFunction(self::CLASS_LEVEL, $functionName);
+        return new UsesFunction(Level::CLASS_LEVEL, $functionName);
     }
 
     /**
@@ -550,12 +539,12 @@ abstract readonly class Metadata
      */
     public static function usesMethod(string $className, string $methodName): UsesMethod
     {
-        return new UsesMethod(self::CLASS_LEVEL, $className, $methodName);
+        return new UsesMethod(Level::CLASS_LEVEL, $className, $methodName);
     }
 
     public static function withoutErrorHandler(): WithoutErrorHandler
     {
-        return new WithoutErrorHandler(self::METHOD_LEVEL);
+        return new WithoutErrorHandler(Level::METHOD_LEVEL);
     }
 
     /**
@@ -563,25 +552,22 @@ abstract readonly class Metadata
      */
     public static function ignorePhpunitWarnings(?string $messagePattern): IgnorePhpunitWarnings
     {
-        return new IgnorePhpunitWarnings(self::METHOD_LEVEL, $messagePattern);
+        return new IgnorePhpunitWarnings(Level::METHOD_LEVEL, $messagePattern);
     }
 
-    /**
-     * @param int<0, 1> $level
-     */
-    protected function __construct(int $level)
+    protected function __construct(Level $level)
     {
         $this->level = $level;
     }
 
     public function isClassLevel(): bool
     {
-        return $this->level === self::CLASS_LEVEL;
+        return $this->level === Level::CLASS_LEVEL;
     }
 
     public function isMethodLevel(): bool
     {
-        return $this->level === self::METHOD_LEVEL;
+        return $this->level === Level::METHOD_LEVEL;
     }
 
     /**
@@ -786,14 +772,6 @@ abstract readonly class Metadata
         return false;
     }
 
-    /**
-     * @phpstan-assert-if-true RunClassInSeparateProcess $this
-     */
-    public function isRunClassInSeparateProcess(): bool
-    {
-        return false;
-    }
-
     /**
      * @phpstan-assert-if-true RunInSeparateProcess $this
      */
