@@ -22,10 +22,9 @@ final readonly class RequiresOperatingSystemFamily extends Metadata
     private string $operatingSystemFamily;
 
     /**
-     * @param int<0, 1>        $level
      * @param non-empty-string $operatingSystemFamily
      */
-    protected function __construct(int $level, string $operatingSystemFamily)
+    protected function __construct(Level $level, string $operatingSystemFamily)
     {
         parent::__construct($level);
 
