@@ -11,11 +11,13 @@ namespace PHPUnit\Event;
 
 use PHPUnit\Event\Tracer\Tracer;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(Facade::class)]
 #[Small]
+#[Group('event-system')]
 final class FacadeTest extends TestCase
 {
     public function testSubscriberRegistrationDoesNotWorkWhenEventFacadeIsSealed(): void
