@@ -11,11 +11,14 @@ namespace PHPUnit\Event\Telemetry;
 
 use function hrtime;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(Snapshot::class)]
 #[Small]
+#[Group('event-system')]
+#[Group('event-system/value-objects')]
 final class SnapshotTest extends TestCase
 {
     public function testConstructorSetsValues(): void
