@@ -11,12 +11,15 @@ namespace PHPUnit\Framework;
 
 use PHPUnit\Framework\Attributes\CoversMethod;
 use PHPUnit\Framework\Attributes\DataProviderExternal;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\TestDox;
 
 #[CoversMethod(Assert::class, 'assertIsNotFloat')]
 #[TestDox('assertIsNotFloat()')]
 #[Small]
+#[Group('framework')]
+#[Group('framework/assertions')]
 final class assertIsNotFloatTest extends TestCase
 {
     #[DataProviderExternal(assertIsFloatTest::class, 'failureProvider')]
