@@ -12,12 +12,14 @@ namespace PHPUnit\Runner;
 use const E_USER_DEPRECATED;
 use function trigger_error;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 use ReflectionClass;
 
 #[CoversClass(ErrorHandler::class)]
 #[Small]
+#[Group('test-runner')]
 final class ErrorHandlerTest extends TestCase
 {
     public function testThrowsExceptionWhenUsingInvalidOrderOption(): void
