@@ -10,17 +10,21 @@
 namespace PHPUnit\TextUI\Configuration;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 
 #[CoversClass(Group::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/value-objects')]
 final class GroupTest extends TestCase
 {
     public function testHasPath(): void
     {
         $name = 'name';
 
-        $this->assertSame($name, (new Group($name))->name());
+        $this->assertSame($name, new Group($name)->name());
     }
 }
