@@ -10,6 +10,7 @@
 namespace PHPUnit\TextUI\Configuration;
 
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\Attributes\UsesClass;
 use PHPUnit\Framework\TestCase;
@@ -22,6 +23,9 @@ use PHPUnit\Framework\TestCase;
 #[UsesClass(FileCollection::class)]
 #[UsesClass(FileCollectionIterator::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/value-objects')]
 final class SourceTest extends TestCase
 {
     public function testHasIncludeDirectories(): void
