@@ -11,12 +11,16 @@ namespace PHPUnit\TextUI\XmlConfiguration;
 
 use function count;
 use PHPUnit\Framework\Attributes\CoversClass;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\Framework\TestCase;
 use PHPUnit\Runner\Version;
 
 #[CoversClass(SchemaFinder::class)]
 #[Small]
+#[Group('textui')]
+#[Group('textui/configuration')]
+#[Group('textui/configuration/xml')]
 final class SchemaFinderTest extends TestCase
 {
     public function testListsAvailableSchemas(): void
